from _typeshed import Incomplete

class ContainerApiMixin:
    def attach(
        self, container, stdout: bool = True, stderr: bool = True, stream: bool = False, logs: bool = False, demux: bool = False
    ): ...
    def attach_socket(self, container, params: Incomplete | None = None, ws: bool = False): ...
    def commit(
        self,
        container,
        repository: str | None = None,
        tag: str | None = None,
        message: Incomplete | None = None,
        author: Incomplete | None = None,
        pause: bool = True,
        changes: Incomplete | None = None,
        conf: Incomplete | None = None,
    ): ...
    def containers(
        self,
        quiet: bool = False,
        all: bool = False,
        trunc: bool = False,
        latest: bool = False,
        since: Incomplete | None = None,
        before: Incomplete | None = None,
        limit: int = -1,
        size: bool = False,
        filters: Incomplete | None = None,
    ): ...
    def create_container(
        self,
        image,
        command: Incomplete | None = None,
        hostname: Incomplete | None = None,
        user: Incomplete | None = None,
        detach: bool = False,
        stdin_open: bool = False,
        tty: bool = False,
        ports: Incomplete | None = None,
        environment: Incomplete | None = None,
        volumes: Incomplete | None = None,
        network_disabled: bool = False,
        name: Incomplete | None = None,
        entrypoint: Incomplete | None = None,
        working_dir: Incomplete | None = None,
        domainname: Incomplete | None = None,
        host_config: Incomplete | None = None,
        mac_address: Incomplete | None = None,
        labels: Incomplete | None = None,
        stop_signal: Incomplete | None = None,
        networking_config: Incomplete | None = None,
        healthcheck: Incomplete | None = None,
        stop_timeout: Incomplete | None = None,
        runtime: Incomplete | None = None,
        use_config_proxy: bool = True,
        platform: Incomplete | None = None,
    ): ...
    def create_container_config(self, *args, **kwargs): ...
    def create_container_from_config(self, config, name: Incomplete | None = None, platform: Incomplete | None = None): ...
    def create_host_config(self, *args, **kwargs): ...
    def create_networking_config(self, *args, **kwargs): ...
    def create_endpoint_config(self, *args, **kwargs): ...
    def diff(self, container): ...
    def export(self, container, chunk_size=2097152): ...
    def get_archive(self, container, path, chunk_size=2097152, encode_stream: bool = False): ...
    def inspect_container(self, container): ...
    def kill(self, container, signal: Incomplete | None = None) -> None: ...
    def logs(
        self,
        container,
        stdout: bool = True,
        stderr: bool = True,
        stream: bool = False,
        timestamps: bool = False,
        tail: str = "all",
        since: Incomplete | None = None,
        follow: Incomplete | None = None,
        until: Incomplete | None = None,
    ): ...
    def pause(self, container) -> None: ...
    def port(self, container, private_port): ...
    def put_archive(self, container, path, data): ...
    def prune_containers(self, filters: Incomplete | None = None): ...
    def remove_container(self, container, v: bool = False, link: bool = False, force: bool = False) -> None: ...
    def rename(self, container, name) -> None: ...
    def resize(self, container, height, width) -> None: ...
    def restart(self, container, timeout: int = 10) -> None: ...
    def start(self, container, *args, **kwargs) -> None: ...
    def stats(self, container, decode: Incomplete | None = None, stream: bool = True, one_shot: Incomplete | None = None): ...
    def stop(self, container, timeout: Incomplete | None = None) -> None: ...
    def top(self, container, ps_args: Incomplete | None = None): ...
    def unpause(self, container) -> None: ...
    def update_container(
        self,
        container,
        blkio_weight: Incomplete | None = None,
        cpu_period: Incomplete | None = None,
        cpu_quota: Incomplete | None = None,
        cpu_shares: Incomplete | None = None,
        cpuset_cpus: Incomplete | None = None,
        cpuset_mems: Incomplete | None = None,
        mem_limit: Incomplete | None = None,
        mem_reservation: Incomplete | None = None,
        memswap_limit: Incomplete | None = None,
        kernel_memory: Incomplete | None = None,
        restart_policy: Incomplete | None = None,
    ): ...
    def wait(self, container, timeout: Incomplete | None = None, condition: Incomplete | None = None): ...



from _typeshed import Incomplete

class DBRPGet:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(self, content: Incomplete | None = None) -> None: ...
    @property
    def content(self): ...
    @content.setter
    def content(self, content) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete
from collections.abc import Iterable, Iterator
from typing import AnyStr, TypeVar, overload

from ..config import PyPIRCCommand

_T = TypeVar("_T")

class register(PyPIRCCommand):
    description: str
    list_classifiers: int
    strict: int
    def initialize_options(self) -> None: ...
    def finalize_options(self) -> None: ...
    def run(self) -> None: ...
    def check_metadata(self) -> None: ...
    def classifiers(self) -> None: ...
    def verify_metadata(self) -> None: ...
    def send_metadata(self) -> None: ...
    def build_post_data(self, action): ...
    def post_to_server(self, data, auth: Incomplete | None = ...): ...

@overload
def make_iterable(values: None) -> list[None]: ...
@overload
def make_iterable(values: AnyStr) -> Iterator[AnyStr]: ...
@overload
def make_iterable(values: Iterable[_T]) -> Iterator[_T]: ...
@overload
def make_iterable(values: _T) -> Iterator[_T]: ...



from __future__ import annotations

import sys
from pathlib import Path

from nodejs_wheel.executable import node


def run(script_name: str):
    sys.exit(
        node(
            [str(Path(__file__).parent / f"{script_name}.js"), *sys.argv[1:]],
            return_completed_process=False,
        )
    )



from _typeshed import Incomplete
from collections.abc import Generator

json_decoder: Incomplete

def stream_as_text(stream) -> Generator[Incomplete, None, None]: ...
def json_splitter(buffer): ...
def json_stream(stream): ...
def line_splitter(buffer, separator: str = "\n"): ...
def split_buffer(stream, splitter: Incomplete | None = None, decoder=...) -> Generator[Incomplete, None, Incomplete]: ...



import contextlib
import enum
import sys
from collections.abc import Callable, Iterable, Iterator
from typing import Any, ClassVar
from typing_extensions import Self

from pynput._util import AbstractListener

class KeyCode:
    _PLATFORM_EXTENSIONS: ClassVar[Iterable[str]]  # undocumented
    vk: int | None
    char: str | None
    is_dead: bool | None
    combining: str | None
    def __init__(self, vk: str | None = None, char: str | None = None, is_dead: bool = False, **kwargs: str) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def join(self, key: Self) -> Self: ...
    @classmethod
    def from_vk(cls, vk: int, **kwargs: Any) -> Self: ...
    @classmethod
    def from_char(cls, char: str, **kwargs: Any) -> Self: ...
    @classmethod
    def from_dead(cls, char: str, **kwargs: Any) -> Self: ...

class Key(enum.Enum):
    alt = 0
    alt_l = alt
    alt_r = alt
    alt_gr = alt
    backspace = alt
    caps_lock = alt
    cmd = alt
    cmd_l = alt
    cmd_r = alt
    ctrl = alt
    ctrl_l = alt
    ctrl_r = alt
    delete = alt
    down = alt
    end = alt
    enter = alt
    esc = alt
    f1 = alt
    f2 = alt
    f3 = alt
    f4 = alt
    f5 = alt
    f6 = alt
    f7 = alt
    f8 = alt
    f9 = alt
    f10 = alt
    f11 = alt
    f12 = alt
    f13 = alt
    f14 = alt
    f15 = alt
    f16 = alt
    f17 = alt
    f18 = alt
    f19 = alt
    f20 = alt
    if sys.platform == "win32":
        f21 = alt
        f22 = alt
        f23 = alt
        f24 = alt
    home = alt
    left = alt
    page_down = alt
    page_up = alt
    right = alt
    shift = alt
    shift_l = alt
    shift_r = alt
    space = alt
    tab = alt
    up = alt
    media_play_pause = alt
    media_volume_mute = alt
    media_volume_down = alt
    media_volume_up = alt
    media_previous = alt
    media_next = alt
    insert = alt
    menu = alt
    num_lock = alt
    pause = alt
    print_screen = alt
    scroll_lock = alt

class Controller:
    _KeyCode: ClassVar[type[KeyCode]]  # undocumented
    _Key: ClassVar[type[Key]]  # undocumented

    if sys.platform == "linux":
        CTRL_MASK: ClassVar[int]
        SHIFT_MASK: ClassVar[int]

    class InvalidKeyException(Exception): ...
    class InvalidCharacterException(Exception): ...

    def __init__(self) -> None: ...
    def press(self, key: str | Key | KeyCode) -> None: ...
    def release(self, key: str | Key | KeyCode) -> None: ...
    def tap(self, key: str | Key | KeyCode) -> None: ...
    def touch(self, key: str | Key | KeyCode, is_press: bool) -> None: ...
    @contextlib.contextmanager
    def pressed(self, *args: str | Key | KeyCode) -> Iterator[None]: ...
    def type(self, string: str) -> None: ...
    @property
    def modifiers(self) -> contextlib.AbstractContextManager[Iterator[set[Key]]]: ...
    @property
    def alt_pressed(self) -> bool: ...
    @property
    def alt_gr_pressed(self) -> bool: ...
    @property
    def ctrl_pressed(self) -> bool: ...
    @property
    def shift_pressed(self) -> bool: ...

class Listener(AbstractListener):
    def __init__(
        self,
        on_press: Callable[[Key | KeyCode | None], None] | None = None,
        on_release: Callable[[Key | KeyCode | None], None] | None = None,
        suppress: bool = False,
        **kwargs: Any,
    ) -> None: ...
    def canonical(self, key: Key | KeyCode) -> Key | KeyCode: ...



from _typeshed import Incomplete

class NetworkApiMixin:
    def networks(self, names: Incomplete | None = None, ids: Incomplete | None = None, filters: Incomplete | None = None): ...
    def create_network(
        self,
        name,
        driver: Incomplete | None = None,
        options: Incomplete | None = None,
        ipam: Incomplete | None = None,
        check_duplicate: Incomplete | None = None,
        internal: bool = False,
        labels: Incomplete | None = None,
        enable_ipv6: bool = False,
        attachable: Incomplete | None = None,
        scope: Incomplete | None = None,
        ingress: Incomplete | None = None,
    ): ...
    def prune_networks(self, filters: Incomplete | None = None): ...
    def remove_network(self, net_id) -> None: ...
    def inspect_network(self, net_id, verbose: Incomplete | None = None, scope: Incomplete | None = None): ...
    def connect_container_to_network(
        self,
        container,
        net_id,
        ipv4_address: Incomplete | None = None,
        ipv6_address: Incomplete | None = None,
        aliases: Incomplete | None = None,
        links: Incomplete | None = None,
        link_local_ips: Incomplete | None = None,
        driver_opt: Incomplete | None = None,
        mac_address: Incomplete | None = None,
    ) -> None: ...
    def disconnect_container_from_network(self, container, net_id, force: bool = False) -> None: ...



from __future__ import annotations

from json import loads
from pathlib import Path
from shutil import copyfile, copytree
from typing import TypedDict, cast

from nodejs_wheel.executable import npm


class PackageJson(TypedDict):
    bin: dict[str, str]


def run_npm(*args: str):
    exit_code = npm(list(args))
    if exit_code != 0:
        raise Exception(f"the following npm command exited with {exit_code=}: {args}")


run_npm("ci")
run_npm("run", "build:cli:dev")

npm_package_dir = Path("packages/pyright")
pypi_package_dir = Path("basedpyright")

copytree(npm_package_dir / "dist", pypi_package_dir / "dist", dirs_exist_ok=True)
for script_path in cast(PackageJson, loads((npm_package_dir / "package.json").read_text()))[
    "bin"
].values():
    _ = copyfile(npm_package_dir / script_path, pypi_package_dir / script_path)



from _typeshed import Incomplete

from .base import DictType

class LogConfigTypesEnum:
    JSON: Incomplete
    SYSLOG: Incomplete
    JOURNALD: Incomplete
    GELF: Incomplete
    FLUENTD: Incomplete
    NONE: Incomplete

class LogConfig(DictType):
    types: type[LogConfigTypesEnum]
    def __init__(self, **kwargs) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, value) -> None: ...
    @property
    def config(self): ...
    def set_config_value(self, key, value) -> None: ...
    def unset_config(self, key) -> None: ...

class Ulimit(DictType):
    def __init__(self, **kwargs) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, value) -> None: ...
    @property
    def soft(self): ...
    @soft.setter
    def soft(self, value) -> None: ...
    @property
    def hard(self): ...
    @hard.setter
    def hard(self, value) -> None: ...

class DeviceRequest(DictType):
    def __init__(self, **kwargs) -> None: ...
    @property
    def driver(self): ...
    @driver.setter
    def driver(self, value) -> None: ...
    @property
    def count(self): ...
    @count.setter
    def count(self, value) -> None: ...
    @property
    def device_ids(self): ...
    @device_ids.setter
    def device_ids(self, value) -> None: ...
    @property
    def capabilities(self): ...
    @capabilities.setter
    def capabilities(self, value) -> None: ...
    @property
    def options(self): ...
    @options.setter
    def options(self, value) -> None: ...

class HostConfig(dict[str, Incomplete]):
    def __init__(
        self,
        version,
        binds: Incomplete | None = None,
        port_bindings: Incomplete | None = None,
        lxc_conf: Incomplete | None = None,
        publish_all_ports: bool = False,
        links: Incomplete | None = None,
        privileged: bool = False,
        dns: Incomplete | None = None,
        dns_search: Incomplete | None = None,
        volumes_from: Incomplete | None = None,
        network_mode: Incomplete | None = None,
        restart_policy: Incomplete | None = None,
        cap_add: Incomplete | None = None,
        cap_drop: Incomplete | None = None,
        devices: Incomplete | None = None,
        extra_hosts: Incomplete | None = None,
        read_only: Incomplete | None = None,
        pid_mode: Incomplete | None = None,
        ipc_mode: Incomplete | None = None,
        security_opt: Incomplete | None = None,
        ulimits: Incomplete | None = None,
        log_config: Incomplete | None = None,
        mem_limit: Incomplete | None = None,
        memswap_limit: Incomplete | None = None,
        mem_reservation: Incomplete | None = None,
        kernel_memory: Incomplete | None = None,
        mem_swappiness: Incomplete | None = None,
        cgroup_parent: Incomplete | None = None,
        group_add: Incomplete | None = None,
        cpu_quota: Incomplete | None = None,
        cpu_period: Incomplete | None = None,
        blkio_weight: Incomplete | None = None,
        blkio_weight_device: Incomplete | None = None,
        device_read_bps: Incomplete | None = None,
        device_write_bps: Incomplete | None = None,
        device_read_iops: Incomplete | None = None,
        device_write_iops: Incomplete | None = None,
        oom_kill_disable: bool = False,
        shm_size: Incomplete | None = None,
        sysctls: Incomplete | None = None,
        tmpfs: Incomplete | None = None,
        oom_score_adj: Incomplete | None = None,
        dns_opt: Incomplete | None = None,
        cpu_shares: Incomplete | None = None,
        cpuset_cpus: Incomplete | None = None,
        userns_mode: Incomplete | None = None,
        uts_mode: Incomplete | None = None,
        pids_limit: Incomplete | None = None,
        isolation: Incomplete | None = None,
        auto_remove: bool = False,
        storage_opt: Incomplete | None = None,
        init: Incomplete | None = None,
        init_path: Incomplete | None = None,
        volume_driver: Incomplete | None = None,
        cpu_count: Incomplete | None = None,
        cpu_percent: Incomplete | None = None,
        nano_cpus: Incomplete | None = None,
        cpuset_mems: Incomplete | None = None,
        runtime: Incomplete | None = None,
        mounts: Incomplete | None = None,
        cpu_rt_period: Incomplete | None = None,
        cpu_rt_runtime: Incomplete | None = None,
        device_cgroup_rules: Incomplete | None = None,
        device_requests: Incomplete | None = None,
        cgroupns: Incomplete | None = None,
    ) -> None: ...

def host_config_type_error(param, param_value, expected): ...
def host_config_version_error(param, version, less_than: bool = True): ...
def host_config_value_error(param, param_value): ...
def host_config_incompatible_error(param, param_value, incompatible_param): ...

class ContainerConfig(dict[str, Incomplete]):
    def __init__(
        self,
        version,
        image,
        command,
        hostname: Incomplete | None = None,
        user: Incomplete | None = None,
        detach: bool = False,
        stdin_open: bool = False,
        tty: bool = False,
        ports: Incomplete | None = None,
        environment: Incomplete | None = None,
        volumes: Incomplete | None = None,
        network_disabled: bool = False,
        entrypoint: Incomplete | None = None,
        working_dir: Incomplete | None = None,
        domainname: Incomplete | None = None,
        host_config: Incomplete | None = None,
        mac_address: Incomplete | None = None,
        labels: Incomplete | None = None,
        stop_signal: Incomplete | None = None,
        networking_config: Incomplete | None = None,
        healthcheck: Incomplete | None = None,
        stop_timeout: Incomplete | None = None,
        runtime: Incomplete | None = None,
    ) -> None: ...



from collections.abc import Iterator
from typing import Any, Literal, overload
from typing_extensions import TypeAlias

from .resource import Collection, Model

_ImageList: TypeAlias = list[Image]  # To resolve conflicts with a method called "list"

class Image(Model):
    @property
    def labels(self) -> dict[str, Any]: ...
    @property
    def short_id(self) -> str: ...
    @property
    def tags(self) -> list[str]: ...
    def history(self) -> list[Any]: ...
    def remove(self, force: bool = False, noprune: bool = False) -> dict[str, Any]: ...
    def save(self, chunk_size: int = 2097152, named: bool = False) -> Iterator[Any]: ...
    def tag(self, repository: str, tag: str | None = None, **kwargs) -> bool: ...

class RegistryData(Model):
    image_name: str
    def __init__(self, image_name: str, *args, **kwargs) -> None: ...
    @property
    def id(self) -> str: ...
    @property
    def short_id(self) -> str: ...
    def pull(self, platform: str | None = None) -> Image: ...
    def has_platform(self, platform): ...
    def reload(self) -> None: ...

class ImageCollection(Collection[Image]):
    model: type[Image]
    def build(self, **kwargs) -> tuple[Image, Iterator[Any]]: ...
    def get(self, name: str) -> Image: ...
    def get_registry_data(self, name, auth_config: dict[str, Any] | None = None) -> RegistryData: ...
    def list(self, name: str | None = None, all: bool = False, filters: dict[str, Any] | None = None) -> _ImageList: ...
    def load(self, data: bytes) -> _ImageList: ...
    @overload
    def pull(self, repository: str, tag: str | None = None, all_tags: Literal[False] = False, **kwargs) -> Image: ...
    @overload
    def pull(self, repository: str, tag: str | None = None, *, all_tags: Literal[True], **kwargs) -> _ImageList: ...
    @overload
    def pull(self, repository: str, tag: str | None, all_tags: Literal[True], **kwargs) -> _ImageList: ...
    def push(self, repository: str, tag: str | None = None, **kwargs): ...
    def remove(self, *args, **kwargs) -> None: ...
    def search(self, *args, **kwargs): ...
    def prune(self, filters: dict[str, Any] | None = None): ...
    def prune_builds(self, *args, **kwargs): ...

def normalize_platform(platform, engine_info): ...



from _typeshed import Incomplete
from typing import ClassVar, Literal

from ._imaging import _PixelAccessor
from .ImageFile import ImageFile

class GbrImageFile(ImageFile):
    format: ClassVar[Literal["GBR"]]
    format_description: ClassVar[str]
    im: Incomplete
    def load(self) -> _PixelAccessor: ...



from _collections_abc import dict_keys
from _typeshed import Incomplete
from collections.abc import Iterable
from re import Pattern
from typing import AnyStr, Final, overload
from typing_extensions import Self

from .caselessdict import CaselessDict

def escape_char(text: str) -> str: ...
def unescape_char(text: AnyStr) -> AnyStr: ...
def tzid_from_dt(dt): ...
def foldline(line: str, limit: int = 75, fold_sep: str = "\r\n ") -> str: ...
def param_value(value: str | list[str] | tuple[str, ...] | Incomplete) -> str: ...

NAME: Final[Pattern[str]]
UNSAFE_CHAR: Final[Pattern[str]]
QUNSAFE_CHAR: Final[Pattern[str]]
FOLD: Final[Pattern[bytes]]
uFOLD: Final[Pattern[str]]
NEWLINE: Final[Pattern[str]]

def validate_token(name: str) -> None: ...
def validate_param_value(value: str, quoted: bool = True) -> None: ...

QUOTABLE: Final[Pattern[str]]

def dquote(val: str) -> str: ...
def q_split(st: str, sep: str = ",", maxsplit: int = -1) -> list[str]: ...
def q_join(lst: Iterable[str], sep: str = ",") -> str: ...

class Parameters(CaselessDict[str]):
    def params(self) -> dict_keys[str, str]: ...
    def to_ical(self, sorted: bool = True) -> bytes: ...
    @classmethod
    def from_ical(cls, st: str, strict: bool = False) -> Self: ...

def escape_string(val: str) -> str: ...
def unescape_string(val: str) -> str: ...
@overload
def unescape_list_or_string(val: list[str]) -> list[str]: ...
@overload
def unescape_list_or_string(val: str) -> str: ...

class Contentline(str):
    strict: bool
    def __new__(cls, value: str | bytes, strict: bool = False, encoding: str = ...) -> Self: ...
    @classmethod
    def from_parts(cls, name: str, params: Parameters, values, sorted: bool = True) -> Self: ...
    def parts(self) -> tuple[str, Parameters, str]: ...
    @classmethod
    def from_ical(cls, ical: str | bytes, strict: bool = False) -> Self: ...
    def to_ical(self) -> bytes: ...

class Contentlines(list[Contentline]):
    def to_ical(self) -> bytes: ...
    @classmethod
    def from_ical(cls, st: str | bytes) -> Self: ...



from _typeshed import Incomplete
from typing import NamedTuple

from .resource import Collection, Model

class Container(Model):
    @property
    def name(self): ...
    @property
    def image(self): ...
    @property
    def labels(self): ...
    @property
    def status(self): ...
    @property
    def health(self): ...
    @property
    def ports(self): ...
    def attach(self, **kwargs): ...
    def attach_socket(self, **kwargs): ...
    def commit(self, repository: str | None = None, tag: str | None = None, **kwargs): ...
    def diff(self): ...
    def exec_run(
        self,
        cmd,
        stdout: bool = True,
        stderr: bool = True,
        stdin: bool = False,
        tty: bool = False,
        privileged: bool = False,
        user: str = "",
        detach: bool = False,
        stream: bool = False,
        socket: bool = False,
        environment: Incomplete | None = None,
        workdir: Incomplete | None = None,
        demux: bool = False,
    ): ...
    def export(self, chunk_size=2097152): ...
    def get_archive(self, path, chunk_size=2097152, encode_stream: bool = False): ...
    def kill(self, signal: Incomplete | None = None): ...
    def logs(self, **kwargs): ...
    def pause(self): ...
    def put_archive(self, path, data): ...
    def remove(self, **kwargs) -> None: ...
    def rename(self, name): ...
    def resize(self, height, width): ...
    def restart(self, **kwargs): ...
    def start(self, **kwargs): ...
    def stats(self, **kwargs): ...
    def stop(self, **kwargs) -> None: ...
    def top(self, **kwargs): ...
    def unpause(self): ...
    def update(self, **kwargs): ...
    def wait(self, **kwargs): ...

class ContainerCollection(Collection[Container]):
    model: type[Container]
    def run(
        self, image, command: Incomplete | None = None, stdout: bool = True, stderr: bool = False, remove: bool = False, **kwargs
    ): ...
    def create(self, image, command: Incomplete | None = None, **kwargs): ...  # type:ignore[override]
    def get(self, container_id): ...
    def list(
        self,
        all: bool = False,
        before: Incomplete | None = None,
        filters: Incomplete | None = None,
        limit: int = -1,
        since: Incomplete | None = None,
        sparse: bool = False,
        ignore_removed: bool = False,
    ): ...
    def prune(self, filters: Incomplete | None = None): ...

RUN_CREATE_KWARGS: Incomplete
RUN_HOST_CONFIG_KWARGS: Incomplete

class ExecResult(NamedTuple):
    exit_code: Incomplete
    output: Incomplete



from typing import Any

from .containers import Container
from .resource import Collection, Model

class Network(Model):
    @property
    def name(self) -> str | None: ...
    @property
    def containers(self) -> list[Container]: ...
    def connect(self, container: str | Container, *args, **kwargs) -> None: ...
    def disconnect(self, container: str | Container, *args, **kwargs) -> None: ...
    def remove(self) -> None: ...

class NetworkCollection(Collection[Network]):
    model: type[Network]
    def create(self, name: str, *args, **kwargs) -> Network: ...  # type:ignore[override]
    def get(self, network_id: str, *args, **kwargs) -> Network: ...  # type:ignore[override]
    def list(self, *args, **kwargs) -> list[Network]: ...
    def prune(self, filters: dict[str, Any] | None = None) -> dict[str, Any]: ...
